Crate mittagleffler

Crate mittagleffler 

Mittag-Leffler Function

This library implements the two-parameter Mittag-Leffler function.

Currently only the algorithm described in the paper by Roberto Garrapa (2015) is implemented. This seems to be the most accurate and computationally efficient method to date for evaluating the Mittag-Leffler function.

use num::complex::Complex64;
use mittagleffler::MittagLeffler;

let alpha = 0.75;
let beta = 1.25;
let z = Complex64::new(1.0, 2.0);
println!("E({}; {}, {}) = {:?}", z, alpha, beta, z.mittag_leffler(alpha, beta));

let z: f64 = 3.1415;
println!("E({}; {}, {}) = {:?}", z, alpha, beta, z.mittag_leffler(alpha, beta));

Acknowledgments

Work on pycaputo was sponsored, in part, by

  • the West University of Timișoara (Romania) under START Grant No. 33580/25.05.2023,
  • the CNCS-UEFISCDI (Romania), under Project No. ROSUA-2024-0002,
  • the “Romanian Hub for Artificial Intelligence - HRIA”, Smart Growth, Digitization and Financial Instruments Program, 2021-2027, MySMIS no. 351416.

The views and opinions expressed herein do not necessarily reflect those of the funding agencies.

Structs

GarrappaMittagLeffler
Parameters for evaluating the Mittag-Leffler function.

Traits

MittagLeffler
Mittag-Leffler function.
MittagLefflerAlgorithm
An algorithm used to evaluate the Mittag-Leffler function.

Functions

mittag_leffler_special